*=====================================================================================*
*                                  analys.do                                     *
*=====================================================================================*

*-------------------------------------------------------------------------------------*
*  van den Berg, Kalmijn, Leopold, 2019, replication files                            *
*  last update: 1 April 2019                                                          *
*  data: soeplong 1984-2015, version 32.1, release 2017                               *
*-------------------------------------------------------------------------------------*

***--------------------------------------------------------------------------***

/* 	This do-files includes the following: 
-  	Descriptives leaving home (Table 1) and returning home (Table 2) analyses
- 	Leaving home analysis (Table 3) (calculation inverse mills prob leaving home)
- 	BIC analyses returning home (Table 4)
- 	Returning home analyses (Table 5)
-	KHB analyses returning home (Table 6) 
-	Survival curve returning home (Figure 1) 
*/


***--------------------------------------------------------------------------***
*** Leaving home analyses
***--------------------------------------------------------------------------***
*** Descriptives
use "${posted}\data.dta", clear

** 	Keep only observations of people younger than 34 and before 2015
drop if syear==2015
drop if n>nmov & nmov!=. | age>33

** 	Center variables 
center age lsatlag gebjahr lsatplag hsatlag
gen age2= c_age*c_age
center age2

* Descriptives leaving home analysis, Table 1
tabstat		leaveh age age2 gebjahr male hconlag ownerlag hhdmemlag 	///
			partnerlag lsatlag regionlag lsatplag 			///
	, statistics(mean max min sd)  
	
foreach var of varlist  pmiclag  eduemplag famlag migb {
fre `var'
}
*

***--------------------------------------------------------------------------***
*** Analyses
// The inverse mills ratio of leaving home will be calculated in these analyses

use "${posted}\data.dta", clear

* 	Prepare data for these analyses 
** 	Keep only observations of people younger than 34 and before 2015
drop if syear==2015
drop if n>nmov & nmov!=. | age>33

** 	Center variables 
center age lsatlag gebjahr lsatplag hsatlag
gen age2= c_age*c_age
center age2

***--------------------------------------------------------------------------***

* Table 3
logit 	leaveh 																		///
				c.c_age c.c_age2 c.c_gebjahr i.male 								///
				c.c_age##i.pmiclag c.c_lsatlag i.hconlag i.ownerlag c.hhdmemlag 	///
				i.eduemplag i.partnerlag i.famlag i.regionlag i.mig		   			///
				c.c_age##c.c_lsatplag, cluster(pid) robust 
estimates store m1
esttab m1 using "${tables}\Table3.rtf", se constant wide   replace

***--------------------------------------------------------------------------***
* Calculate inverse mills ration 
predictnl pr = invlogit(xb()), se(se)
predict p1, xb
replace p1 = -p1
gen phi=(1/sqrt(2*_pi))*exp(-(p1^2/2))
gen capphi=normal(p1)
gen invmills=phi/(1-capphi)

* keep one observation per person
keep if n == nmov
xtile lp2 = invmills, nq(5)
keep pid invmills lp2 pr

save "${posted}\data2.dta", replace


***--------------------------------------------------------------------------***
***	Returning home analyses 
***--------------------------------------------------------------------------***
*** Descriptives
use "${posted}\data.dta", clear
merge m:1 pid using "${posted}\data2.dta", keep(3) nogen

**	Prepare data for these analyses
***	Sample selection returning home analyses 
drop if hsatlag==. | hsat1==. | dsatlag==. | dsat1==. | invmills==.
drop if age>min_agert 	
drop if age>35
keep if n2<=5 & n2>=1				//only keep till 5 years after leaving

*** Standardizing variables
foreach var of varlist agemov invmills hsatchange lsatchange dsatchange {
center `var'
egen std`var'= std(`var')
center std`var'
}
*
gen age2= c_agemov*c_agemov
center age2

* Descriptives returning home analysis, Table 2
keep if n2==1

tabstat		c_invmills hsatchange lsatchange dsatchange 				///
			poorlag hconlag partnered unpartnered 						///
	, statistics(mean max min sd)  f(%9.3g) 
fre empstat 


***--------------------------------------------------------------------------***
*** Analyses 

use "${posted}\data.dta", clear
merge m:1 pid using "${posted}\data2.dta", keep(3) nogen

*	Prepare data for these analyses
**	Sample selection returning home analyses 
drop if hsatlag==. | hsat1==. | dsatlag==. | dsat1==. | invmills==.
drop if age>min_agert 	
drop if age>35
keep if n2<=5 & n2>=1				//only keep till 5 years after leaving

** Standardizing variables
foreach var of varlist agemov invmills hsatchange lsatchange dsatchange {
center `var'
egen std`var'= std(`var')
center std`var'
}
*
gen age2= c_agemov*c_agemov
center age2


***--------------------------------------------------------------------------***
* BIC analyses, Table 4

** Model 1: inverse mills ratio
probit return i.n2 c_invmills  , cluster(pid)  
fitstat, save
estimates store m1r

** Model 2: age
probit return i.n2 c.c_agemov c.c_age2, cluster(pid) 
fitstat, diff
estimates store m2r

** Model 3: age and inverse mills
probit return i.n2 c.c_agemov c.c_age2 c_invmills, cluster(pid)  
fitstat, save
estimates store m3r
probit return i.n2 c_invmills  , cluster(pid)  
fitstat, diff

esttab m1r m2r m3r using "${tables}\Table4.rtf", constant wide   replace
***--------------------------------------------------------------------------***
* Table 5

** Model 1: Inverse mills ratio
probit return 																	///
				i.n2 c_invmills													///
				, cluster(pid)  
estimates store r1

*** Model 2: dissatisfied with life after leaving home
probit return 														  			/// 
				i.n2 c_invmills 										 		/// 
				c_hsatchange c_lsatchange c_dsatchange							///
				, cluster(pid)
estimates store r2

** Model 3: Adverse living conditions
probit return 														  			/// 
				i.n2 c_invmills 										 		/// 
				c_hsatchange c_lsatchange c_dsatchange							///
				i.poorlag i.hconlag 									 		///	 				
				, cluster(pid)
estimates store r3

** Model 4: turningpoints
probit return 														  			/// 
				i.n2 c_invmills 										 		/// 
				c_hsatchange c_lsatchange c_dsatchange							///
				i.poorlag i.hconlag 									 		///	 							 				///	 Adverse living conditions
				i.partnered i.unpartnered i.empstat 							/// 
				, cluster(pid)
estimates store r4
				
esttab r1 r2 r3 r4 using "${tables}\Table5.rtf", se constant wide   replace

***--------------------------------------------------------------------------***
* Khb analyses, Table 6

** Model 2
khb probit return  c_invmills  ||												/// 
	c_hsatchange c_lsatchange c_dsatchange			 							/// 
	, concomitant(i.n2)  														///
	robust cluster(pid) summary

** Model 3
khb probit return  c_invmills  ||												///
	i.poorlag i.hconlag															/// 
	, concomitant(i.n2 c_hsatchange c_lsatchange c_dsatchange  )				///
	robust cluster(pid) summary

** Model 4	
khb probit return  c_invmills  ||												/// 
	partnered unpartnered i.empstat 											/// 
	, concomitant(i.n2  c_hsatchange c_lsatchange c_dsatchange i.poorlag i.hconlag	)												///
	robust cluster(pid) summary
	
khb probit return  c_invmills  ||												/// 
	c_hsatchange c_lsatchange c_dsatchange			 							/// 
	i.poorlag i.hconlag															/// 
	partnered unpartnered i.empstat 											/// 
	, concomitant(i.n2)															///
	robust cluster(pid) summary disentangle

***--------------------------------------------------------------------------***
*** Figure 1: Survival curve
***--------------------------------------------------------------------------***
use "${posted}\data.dta", clear
merge m:1 pid using "${posted}\data2.dta", keep(3) nogen

*	Sample selection returning home analyses 
drop if age>min_agert | age>35 | n2>5 | n2<0

* Set data as event-data
stset n2, id(pid) failure(return)

* Make quintiles inverse mill's ratio
xtile lp3 = invmills, nq(5)

foreach num of numlist 1 2 3 4 5 {
		sts gen km`num'=s if lp3==`num'
		}
		*
		
sts graph, by(lp3) title("Figure 1: Survival Curve for Returning Home, by Likelihood to Leave Home", size(small) color(black))                               							///       
             graphregion(color(white) fcolor(white) icolor(white)) 				///
			 ylabel(0.85(0.05)1, labsize(vsmall) angle(0))    					///        
             xlabel(1(1)5, labsize(vsmall)) xtitle("Years after leaving home", 	///
			 size(vsmall)) ytitle(")",   										///
             size(vsmall))  yscale(titlegap(2)) xscale(titlegap(2)) 			///                                                                                                                                                                                         ///
             plotregion(color(white) fcolor(white) icolor(white)) 				///
			 legend(title("Inverse mills ratio", 								///
			 size(vsmall) col(black)) size(vsmall) rows(1) lab(1 "1st")  		///
             lab(2 "2nd") lab(3 "3rd") lab(4 "4th") lab(5 "5th")) 
	graph save "${graphs}/fig1.gph", replace
			 		
		
